@@ -1,4 +1,4 @@
-#![deny(missing_docs)]
+#![warn(missing_docs)]
 // This is an HTML parser. HTML can be untrusted input from the internet.
 #![forbid(unsafe_code)]
 #![doc = include_str!("../README.md")]
@@ -7,13 +7,18 @@ mod emitter;
 mod entities;
 mod error;
 mod machine;
+mod machine_helper;
 mod never;
+mod read_helper;
 mod reader;
 mod tokenizer;
 mod utils;
 
 #[cfg(feature = "integration-tests")]
-pub use utils::State;
+mod slow_reader;
+
+#[cfg(feature = "integration-tests")]
+pub use {slow_reader::SlowReader, utils::State};
 
 pub use emitter::{DefaultEmitter, Doctype, Emitter, EndTag, StartTag, Token};
 pub use error::Error;
